@@ -1,12 +1,12 @@
 /*
- * Copyright (c) 2001-2003, 2005, 2006 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 2001-2003, 2005-2007 Sendmail, Inc. and its suppliers.
  *      All rights reserved.
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the LICENSE file which can be found at the top level of
  * the sendmail distribution.
  *
- *	$Id: ldap.h,v 1.32 2006/08/30 22:56:58 ca Exp $
+ *	$Id: ldap.h,v 1.34 2008/11/17 21:02:54 ca Exp $
  */
 
 #ifndef	SM_LDAP_H
@@ -91,6 +91,10 @@ struct sm_ldap_struct
 	/* ldapmap_lookup options */
 	char		ldap_attrsep;
 
+# if _FFR_LDAP_NETWORK_TIMEOUT
+	int		ldap_networktmo;
+# endif /* _FFR_LDAP_NETWORK_TIMEOUT */
+
 	/* Linked list of maps sharing the same LDAP binding */
 	void		*ldap_next;
 };
