@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2003 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 2000-2003, 2007 Sendmail, Inc. and its suppliers.
  *	All rights reserved.
  *
  * By using this file, you agree to the terms and conditions set
@@ -9,7 +9,7 @@
  */
 
 #include <sm/gen.h>
-SM_RCSID("@(#)$Id: config.c,v 1.30 2003/12/10 03:19:07 gshapiro Exp $")
+SM_RCSID("@(#)$Id: config.c,v 1.31 2007/03/14 21:21:49 ca Exp $")
 
 #include <stdlib.h>
 #include <sm/heap.h>
@@ -247,5 +247,14 @@ char *SmCompileOptions[] =
 #if SM_VA_STD
 	"SM_VA_STD",
 #endif /* SM_VA_STD */
+#if USEKSTAT
+	"USEKSTAT",
+#endif /* USEKSTAT */
+#if USEPROCMEMINFO
+	"USEPROCMEMINFO",
+#endif /* USEPROCMEMINFO */
+#if USESWAPCTL
+	"USESWAPCTL",
+#endif /* USESWAPCTL */
 	NULL
 };
