@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2001, 2004 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 2000-2001, 2004, 2006 Sendmail, Inc. and its suppliers.
  *      All rights reserved.
  * Copyright (c) 1990, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -13,11 +13,12 @@
  */
 
 #include <sm/gen.h>
-SM_RCSID("@(#)$Id: flags.c,v 1.22 2004/03/03 19:20:29 ca Exp $")
+SM_RCSID("@(#)$Id: flags.c,v 1.23 2006/12/19 19:44:23 ca Exp $")
 #include <sys/types.h>
 #include <sys/file.h>
 #include <errno.h>
 #include <sm/io.h>
+#include "local.h"
 
 /*
 **  SM_FLAGS -- translate external (user) flags into internal flags
@@ -31,9 +32,9 @@ SM_RCSID("@(#)$Id: flags.c,v 1.22 2004/03/03 19:20:29 ca Exp $")
 
 int
 sm_flags(flags)
-	register int flags;
+	int flags;
 {
-	register int ret;
+	int ret;
 
 	switch(SM_IO_MODE(flags))
 	{
